pub struct RequirementControlMapV1 {
pub schema_version: String,
pub requirement_control_map_id: String,
pub regulatory_regime_profile_id: String,
pub mappings: Vec<RequirementControlMappingEntryV1>,
pub gap_classification_default: String,
pub owner_ref: String,
}Fields
schema_version: Stringrequirement_control_map_id: Stringregulatory_regime_profile_id: Stringmappings: Vec<RequirementControlMappingEntryV1>gap_classification_default: Stringowner_ref: StringTrait Implementations
Sourceimpl Clone for RequirementControlMapV1
impl Clone for RequirementControlMapV1
Sourcefn clone(&self) -> RequirementControlMapV1
fn clone(&self) -> RequirementControlMapV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RequirementControlMapV1
impl Debug for RequirementControlMapV1
Sourceimpl<'de> Deserialize<'de> for RequirementControlMapV1
impl<'de> Deserialize<'de> for RequirementControlMapV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RequirementControlMapV1
Sourceimpl JsonSchema for RequirementControlMapV1
impl JsonSchema for RequirementControlMapV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RequirementControlMapV1
impl PartialEq for RequirementControlMapV1
Sourcefn eq(&self, other: &RequirementControlMapV1) -> bool
fn eq(&self, other: &RequirementControlMapV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RequirementControlMapV1
impl Serialize for RequirementControlMapV1
impl StructuralPartialEq for RequirementControlMapV1