pub struct RequirementControlMappingEntryV1 {
pub requirement: String,
pub control: String,
pub evidence_family: String,
}Fields
requirement: Stringcontrol: Stringevidence_family: StringTrait Implementations
Sourceimpl Clone for RequirementControlMappingEntryV1
impl Clone for RequirementControlMappingEntryV1
Sourcefn clone(&self) -> RequirementControlMappingEntryV1
fn clone(&self) -> RequirementControlMappingEntryV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for RequirementControlMappingEntryV1
impl<'de> Deserialize<'de> for RequirementControlMappingEntryV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RequirementControlMappingEntryV1
Sourceimpl JsonSchema for RequirementControlMappingEntryV1
impl JsonSchema for RequirementControlMappingEntryV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RequirementControlMappingEntryV1
impl PartialEq for RequirementControlMappingEntryV1
Sourcefn eq(&self, other: &RequirementControlMappingEntryV1) -> bool
fn eq(&self, other: &RequirementControlMappingEntryV1) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RequirementControlMappingEntryV1